/* $Id: WorkArea.h,v 1.4 1999/11/06 05:51:00 glgay Exp $ */
/*
 Copyright (C) 1993, 1994 Jettero Heller
 Copyright (C) 1994, 1995 Peter Williams
 Copyright (C) 1999       Gerald L. Gay
 
 This library is free software; you can redistribute it and/or
 modify it under the terms of the GNU Library General Public License 
 version 2 as published by the Free Software Foundation.

 This library is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 Library General Public License for more details.

 You should have received a copy of the GNU Library General Public
 License along with this library; see the file COPYING.  If not,
 write to the Free Software Foundation, Inc., 675 Mass Ave, 
 Cambridge, MA 02139, USA.
*/


#if !defined(xarm_workarea_h)
#define xarm_workarea_h

/* ======================================================================= */
/* Include(s): */
#include <Xarm/RowColumn.h>

class WorkAreaClass : public RowColumnClass {
 protected:
   WorkAreaClass() {} /* only a derived class can make this */
};

typedef XarmRawWidget<WorkAreaClass, false> WorkArea;

#endif
